py-rmrk-tools
=============

A port of [rmrk-tools](https://github.com/rmrk-team/rmrk-tools) for Python.

Installation
------------

Python 3.9 and higher supported.

```console
pip install py-rmrk-tools
```

ToDo
----

- [ ] Entities definition
    - [x] NFT
    - [ ] Collection
- [ ] CLI
- [ ] Consolidator
- [ ] RemarkListener
- [ ] fetchRemarks
- [ ] IPFS helpers
- [ ] Validation
